indexWhere method
The first index in the list that satisfies the provided test.
Searches the list from index start to the end of the list.
The first time an object o is encountered so that test(o) is true,
the index of o is returned.
Implementation
int indexWhere(bool Function(T element) test, [int start = 0]) {
return _items.indexWhere(test, start);
}